# ML Ops Quickstart
[![Code coverage](https://codecov.io/github/fragiletech/mloq/coverage.svg)](https://codecov.io/github/fragiletech/mloq)
[![PyPI package](https://badgen.net/pypi/v/mloq)](https://pypi.org/project/mloq/)
[![Latest docker image](https://badgen.net/docker/pulls/fragiletech/mloq)](https://hub.docker.com/r/fragiletech/mloq/tags)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![license: MIT](https://img.shields.io/badge/license-MIT-green.svg)](https://opensource.org/licenses/MIT)

Package for initializing ML projects following ML Ops best practices.
